@@ -35,11 +35,8 @@ def run(runner, debug=False, text=False, exit_code_on_error=1):
         else:
             respond(data)
     except Exception, e:
-        all_info_lines = traceback.format_exception(sys.exc_type, sys.exc_value, sys.exc_traceback)
-        all_info_text = ''.join(all_info_lines)
-        exc_info_lines = traceback.format_exception_only(sys.exc_type, sys.exc_value)
-        exc_info_text = ''.join(exc_info_lines)
-        respond(all_info_text, exc_info_text, success=False)
+        log.exception('got an exception')
+        respond(e, str(e), success=False)
         exit(exit_code_on_error)
 
 
@@ -50,8 +47,10 @@ def execute(obj, args, exit_code_on_error=1):
         text = args.text
     run(lambda: call(method, vars(args)), args.debug, text, exit_code_on_error)
 
+
+# Leaving for backward compatibility until all apps upgraded
+# Use directly logger.init()
 def init_log(name, args):
-    if args.debug:
-        logger.console = True
-        logger.level = logging.DEBUG
-    logger.init('/tmp/{}.log'.format(name))
+    console = True if args.debug else False
+    level = logging.DEBUG if args.debug else logging.INFO
+    logger.init(level, console, '/tmp/{}.log'.format(name))
